@@ -24,9 +24,11 @@ def validate_classifier(configini,seconds,target):
     ## get fps from videoinfo csv
     videoinfocsv = os.path.join(projectPath, 'logs', 'video_info.csv')
     fpsdf = pd.read_csv(videoinfocsv)
+    fileCounter = 0
 
     #main loop
     for i in csvList:
+        print('Processing file: ' + os.path.basename(i) + ' File ' + fileCounter + ' / ' + str(len(csvList)))
         df = pd.read_csv(i)
         csvname = os.path.basename(i).split('.')[0]
         fps = int(fpsdf['fps'].loc[(fpsdf['Video'] == csvname)])
@@ -34,6 +36,7 @@ def validate_classifier(configini,seconds,target):
         probabilitycolumn = df['Probability_' + target]
         framesBehavior = [i for i, e in enumerate(targetcolumn) if e != 0]  ##get frame numbers with behavior into a list( df column = 1)
 
+
         #get all bouts in a list
         bouts = []
         for k, g in groupby(enumerate(framesBehavior), lambda x: x[0] - x[1]):  ##group by and split # get the bouts in a list of list# groupby splits it base on continuous bout
